==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/cs_CZ.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Address book name" : "Název adresáře kontaktů",
    "No contacts in here" : "Nejsou zde žádné kontakty",
    "Name" : "Název",
    "Organization" : "Organizace",
    "Title" : "Název",
    "Add field ..." : "Přidat pole...",
    "Import" : "Importovat",
    "Add contact" : "Přidat kontakt",
    "No search result for {query}" : "Žádný nález pro {query}",
    "All contacts" : "Všechny kontakty",
    "Not grouped" : "Neseskupené",
    "Post Office Box" : "Poštovní schránka",
    "Postal Code" : "Poštovní směrovací číslo",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Country" : "Země",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "New contact" : "Nový kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
    "Invalid file type." : "Neplatný typ souboru.",
    "Nickname" : "Přezdívka",
    "Notes" : "Poznámky",
    "Website" : "Stránka",
    "Federated Cloud ID" : "Sdružené cloud ID",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Groups" : "Skupiny",
    "Birthday" : "Narozeniny",
    "Email" : "Email",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Settings" : "Nastavení"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/cs_CZ.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Address book name" : "Název adresáře kontaktů",
    "No contacts in here" : "Nejsou zde žádné kontakty",
    "Name" : "Název",
    "Organization" : "Organizace",
    "Title" : "Název",
    "Add field ..." : "Přidat pole...",
    "Import" : "Importovat",
    "Add contact" : "Přidat kontakt",
    "No search result for {query}" : "Žádný nález pro {query}",
    "All contacts" : "Všechny kontakty",
    "Not grouped" : "Neseskupené",
    "Post Office Box" : "Poštovní schránka",
    "Postal Code" : "Poštovní směrovací číslo",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Country" : "Země",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "New contact" : "Nový kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
    "No contacts in file. Only VCard files are allowed." : "Žádné kontakty v souboru. Pouze soubory vCard jsou povoleny.",
    "Nickname" : "Přezdívka",
    "Notes" : "Poznámky",
    "Website" : "Stránka",
    "Federated Cloud ID" : "Sdružené cloud ID",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Groups" : "Skupiny",
    "Birthday" : "Narozeniny",
    "Email" : "Email",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Social Network" : "Sociální síť",
    "Settings" : "Nastavení"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
